@@ -18,6 +18,8 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+
+
 class CreateContainerGroupRequest(RpcRequest):
 
 	def __init__(self):
@@ -242,6 +244,8 @@ class CreateContainerGroupRequest(RpcRequest):
 				self.add_query_param('Container.' + str(i + 1) + '.Tty', Containers[i].get('Tty'))
 			if Containers[i].get('Gpu') is not None:
 				self.add_query_param('Container.' + str(i + 1) + '.Gpu', Containers[i].get('Gpu'))
+			if Containers[i].get('EnvironmentVarHide') is not None:
+				self.add_query_param('Container.' + str(i + 1) + '.EnvironmentVarHide', Containers[i].get('EnvironmentVarHide'))
 
 	def get_ResourceOwnerId(self):
 		return self.get_query_params().get('ResourceOwnerId')
@@ -448,6 +452,12 @@ class CreateContainerGroupRequest(RpcRequest):
 			if Volumes[i].get('Type') is not None:
 				self.add_query_param('Volume.' + str(i + 1) + '.Type', Volumes[i].get('Type'))
 
+			if Volumes[i].get('HostPathVolume.Type') is not None:
+				self.add_query_param('Volume.' + str(i + 1) + '.HostPathVolume.Type', Volumes[i].get('HostPathVolume.Type'))
+
+			if Volumes[i].get('HostPathVolume.Path') is not None:
+				self.add_query_param('Volume.' + str(i + 1) + '.HostPathVolume.Path', Volumes[i].get('HostPathVolume.Path'))
+
 	def get_ContainerGroupName(self):
 		return self.get_query_params().get('ContainerGroupName')
 
