@@ -35,6 +35,12 @@ class DescribeContainerGroupsRequest(RpcRequest):
 	def set_ContainerGroupIds(self,ContainerGroupIds):
 		self.add_query_param('ContainerGroupIds',ContainerGroupIds)
 
+	def get_ResourceGroupId(self):
+		return self.get_query_params().get('ResourceGroupId')
+
+	def set_ResourceGroupId(self, ResourceGroupId):
+		self.add_query_param('ResourceGroupId', ResourceGroupId)
+
 	def get_NextToken(self):
 		return self.get_query_params().get('NextToken')
 
@@ -66,14 +72,14 @@ class DescribeContainerGroupsRequest(RpcRequest):
 		self.add_query_param('OwnerId',OwnerId)
 
 	def get_Tags(self):
-		return self.get_query_params().get('Tagss')
+		return self.get_query_params().get('Tags')
 
 	def set_Tags(self,Tags):
 		for i in range(len(Tags)):
 			if Tags[i].get('Key') is not None:
-				self.add_query_param('Tag.' + str(i + 1) + '.Key' , Tags[i].get('Key'))
+				self.add_query_param('Tag.' + str(i + 1) + '.Key', Tags[i].get('Key'))
 			if Tags[i].get('Value') is not None:
-				self.add_query_param('Tag.' + str(i + 1) + '.Value' , Tags[i].get('Value'))
+				self.add_query_param('Tag.' + str(i + 1) + '.Value', Tags[i].get('Value'))
 
 
 	def get_VSwitchId(self):
